#
# spec file for package kgeotag
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kgeotag
Version:        1.8.0
Release:        1.1
Summary:        A photo geotagging utility
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/kgeotag/
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        kgeotag.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KExiv2Qt6) >= 5.1.0
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Marble) >= 24.12.0
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Recommends:     marble

%description
KGeoTag is a standalone geotagging program.
Images can be associated with geographic coordinates by different means: On the
one hand, a matching with GPX encoded geodata can be done, on the other hand,
the coordinates can be set manually, either via drag and drop onto a map, via
bookmarks or by manually supplying them. The coordinates can be stored in the
images' Exif header and/or in XMP sidecar files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE -DQT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html

%files
%license LICENSES/*
%doc CHANGELOG.rst README.md
%doc %lang(en) %{_kf6_htmldir}/en/kgeotag
%{_kf6_applicationsdir}/org.kde.kgeotag.desktop
%{_kf6_appstreamdir}/org.kde.kgeotag.appdata.xml
%{_kf6_bindir}/kgeotag
%{_kf6_iconsdir}/hicolor/*/apps/kgeotag.png
%{_kf6_sharedir}/kgeotag/

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kgeotag

%changelog
* Sun Mar  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 1.8.0
  https://kgeotag.kde.org/news/2025/kgeotag-1.8.0-released/
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.7.0
  https://kgeotag.kde.org/news/2024/kgeotag-1.7.0-released/
* Fri Oct 11 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.6.0
  https://kgeotag.kde.org/news/2024/kgeotag-1.6.0-released/
  * Coordinates format is now configurable
  * It's now possible to (re-)assign all currently selected images
    to the current map center using a keyboard shortcut.
  * Updated the timezones data files to 2024b
  * Fixed a crash when removing a GPX track and moving the
    "track walker" slider afterwards.
  * Changes to the image list layout (combined/separate) are now
    displayed correctly (again).
  * The window state saved by the KXmlGuiWindow/KMainWindow class
    is now used to restore the dock arrangement
  * Closed floating docks are now properly restored by using
    "Set default dock arrangement" (kde#488597)
* Thu Jan 25 2024 Wolfgang Bauer <wbauer1@a1.net>
- Update to 1.5.0
  * It's now possible to find the chronologically closest track
    point for an unassigned image and center the map there. If an
    image has been taken in the time between two tracks, one can
    find the last or first coordinates of the track recorded before
    or afterwards (whichever is closer) and use them as a basis for
    manual tagging.
  * The timezones data files have been updated to Timezone Boundary
    Builder's release 2023d.
* Tue Oct 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.4.0
  * KGeoTag now supports handling of some TIFF-based RAW image
    formats
  * Dependencies update
  * Updated the timezones data files to 2022g
  * The compile_timezones_data.py script now derives timezone
    colors from the timezone name rather than counting a color
    up on a sorted list.
* Sun Nov 27 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the 'License' tag
* Tue Sep  6 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.3.1
  * Hotfix: Due to a problem with the tarme.rb releaseme script,
    the 1.3.0 tarball lacked all l10n data. We thus had to withdraw
    the release and tag a new one.
  * New: When using the split images list view and tagging images
    manually, the "assigned" image list now scrolls to the last (or
    only) tagged image and highlights it, so that it's immediately
    accessible for e.g. further corrections.
  * New: Allow setting coordinates directly from the clipboard. As
    of now, Google Maps' format as well as OpenStreetMap's Geo URI
    scheme is supported. (kde#458537)
  * New: It is now possible to open an image with the system's
    default image viewer (for closer inspection), either from the
    image list(s), or from the preview widget.
  * Bugfix: Use "Folder", not "Directory" according to KDE's
    style/vocabulary guidelines. (kde#457020)
  * New: Files and/or directories given on the command line are now
    loaded after startup (which can e.g. also be triggered via
    "Open with" from a file manager like Dolphin).
  * Update: Updated the timezones data files to 2021c.
  * Change: As Marble now has a decent versioning scheme (at least
    since the KDE Apps release 21.12.3), KGeoTag now has a defined
    dependency for Marble: It now depends on at least Marble
    21.12.3. It actually can be built against older versions as
    well, but due to the lack of proper version bumps, there was no
    way to define a definitive version to depend on until now.
  * New/Bugfix: Added a handbook stub. (kde#452534)
* Sun Nov 14 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.2.0
  * Enhancement: KGeoTag now checks if the timezone data files
    could actually be loaded and displays a warning about timezone
    detection not working if not.
  * Bugfix: Made selecting all entries of an image list work again
    via the standard shortcut CTRL+A. This one was assigned to
    "Assign images to GPS data", which can now be  accessed via
    CTRL+M.  (kde#445023)
  * Bugfix: QMimeDatabase::mimeTypeForFile now returns
    application/xml+gpx as a GPX file's MIME type instead of
    application/x-gpx+xml - at least here on my stable Gentoo
    machine. This made KGeoTag refuse to load any GPX file. Now,
    both MIME types are accepted.
  * Change: Suppressed a warning by bumping cmake_minimum_required
    to 3.16.0.
* Mon Oct 25 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.1.0
  * Bugfix: When walking along a track, the date and time were
    displayed to be in the set timezone, but not actually converted
    to it. Now, the timestamps are translated correctly.
  * Enhancement: Added an "Assign images to GPS data" main menu
    entry. This one triggers an automatic image assignment af all
    loaded images, like "(Re)Assign all images" from the "Automatic
    assignment" dock. The search type to perform can be defined in
    the settings.
  * Bugfix: Enabled exact matching also if a used GPX track and/or
    the image metadata contain milliseconds. If so, the
    `QHash<QDateTime, ...>::contains()` call used to search for
    exact matches won't yield a result, even if there's a
    seconds-exact match (if not also the milliseconds matched, and
    this is quite unlikely).
- Drop 0001-Don-t-look-for-a-specific-Marble-version.patch, merged
  upstream
- Change URL to new project homepage
* Wed Aug 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix the marble detection:
  * 0001-Don-t-look-for-a-specific-Marble-version.patch
* Sun Jun 27 2021 Wolfgang Bauer <wbauer@tmo.at>
- Initial package
